@@ -203,7 +203,7 @@ class CLI(cl1.CLI):
 						try:
 							del CONFIG.dictionary["aliases"][alias]
 							CONFIG.dictionary["aliases"][new_alias] = alias_info
-							CONFIG.save()
+							utils.save_config_safely()
 						except: success = False
 						if success:
 							self.stop(message=f"Successfully renamed alias {alias} to {new_alias}.", json=JSON)
