@@ -103,7 +103,7 @@ class Agent(object):
 			if not response["success"]: return response
 		else:
 			if not os.path.exists(path):
-				return r3sponse.error_response(f"Key path [{path}] does not exist.")
+				return r3sponse.error(f"Key path [{path}] does not exist.")
 
 		# check agent connection.
 		output = utils.__execute__(["ssh-add", "-L"])
@@ -125,10 +125,10 @@ class Agent(object):
 					reattempt=False,
 				)
 			else:
-				return r3sponse.error_response("Failed to communicate with the ssh-agent. Try logging out the current system user & logging back in (or execute [$ eval `ssh-agent`]).")
+				return r3sponse.error("Failed to communicate with the ssh-agent. Try logging out the current system user & logging back in (or execute [$ eval `ssh-agent`]).")
 
 		# with passphrase.
-		if smart_card or passphrase != None:
+		if smart_card or passphrase not in [False, None, "", "none", "None"]:
 			#self.initialize()
 			if smart_card:
 				path = smart_cards.path
@@ -187,9 +187,9 @@ class Agent(object):
 
 			# check success.
 			if "incorrect passphrase" in output.lower():
-				return r3sponse.error_response("Provided an incorrect passphrase.")
+				return r3sponse.error("Provided an incorrect passphrase.")
 			elif "incorrect pin" in output.lower():
-				return r3sponse.error_response("Provided an incorrect pin code.")
+				return r3sponse.error("Provided an incorrect pin code.")
 			elif "Failed to communicate" in output or "agent refused operation" in output or "Error connecting to agent" in output or "Connection refused" in output:
 				if reattempt:
 					ssh.utils.ssh_agent()
@@ -208,19 +208,19 @@ class Agent(object):
 						reattempt=False,
 					)
 				else:
-					return r3sponse.error_response("Failed to communicate with the ssh-agent. Try logging out the current system user & logging back in (or execute [$ eval `ssh-agent`]).")
+					return r3sponse.error("Failed to communicate with the ssh-agent. Try logging out the current system user & logging back in (or execute [$ eval `ssh-agent`]).")
 			elif "Identity added:" in output or "Card added:" in output: 
-				return r3sponse.success_response(f"Successfully added key [{path}] to the ssh agent.")
+				return r3sponse.success(f"Successfully added key [{path}] to the ssh agent.")
 			elif output != "": 
-				return r3sponse.error_response(f"Failed to add key [{path}] to the ssh agent, error: {output}")
+				return r3sponse.error(f"Failed to add key [{path}] to the ssh agent, error: {output}")
 			else: 
-				return r3sponse.error_response(f"Failed to add key [{path}] to the ssh agent.")
+				return r3sponse.error(f"Failed to add key [{path}] to the ssh agent.")
 
 			# handle eof.
 			"""try:
 				spawn.expect(pexpect.EOF, timeout=timeout)
 			except pexpect.ExceptionPexpect as epe:
-				return r3sponse.error_response(f"Failed to add key [{path}] to the ssh agent #3.")"""
+				return r3sponse.error(f"Failed to add key [{path}] to the ssh agent #3.")"""
 
 		# without pass.
 		else:
@@ -228,11 +228,11 @@ class Agent(object):
 
 			# check success.
 			if "Failed to communicate" in output or "agent refused operation" in output or "Error connecting to agent" in output or "Connection refused" in output:
-				return r3sponse.error_response("Failed to communicate with the ssh-agent.")
+				return r3sponse.error("Failed to communicate with the ssh-agent.")
 			elif "Identity added:" in output: 
-				return r3sponse.success_response(f"Successfully added key [{path}] to the ssh agent.")
+				return r3sponse.success(f"Successfully added key [{path}] to the ssh agent.")
 			else: 
-				return r3sponse.error_response(f"Failed to add key [{path}] to the ssh agent.")
+				return r3sponse.error(f"Failed to add key [{path}] to the ssh agent.")
 
 		#
 	def delete(self):
@@ -242,11 +242,11 @@ class Agent(object):
 
 		# check success.
 		if "Could not open a connection to your authentication agent." in output:
-			return r3sponse.error_response("Failed to communicate with the ssh-agent.")
+			return r3sponse.error("Failed to communicate with the ssh-agent.")
 		elif "All identities removed." in output: 
-			return r3sponse.success_response(f"Successfully removed all keys from the ssh agent.")
+			return r3sponse.success(f"Successfully removed all keys from the ssh agent.")
 		else: 
-			return r3sponse.error_response(f"Failed to remove all keys from the ssh agent.")
+			return r3sponse.error(f"Failed to remove all keys from the ssh agent.")
 
 		#
 	def list(self):
@@ -256,12 +256,12 @@ class Agent(object):
 		# list keys.
 		output = utils.__execute__(command=["ssh-add", "-L"], return_format="array")
 		if "Failed to communicate" in output:
-			return r3sponse.error_response("Failed to communicate with the ssh-agent.")
+			return r3sponse.error("Failed to communicate with the ssh-agent.")
 		elif "The agent has no identities." in output:
 			keys = []
 		else:
 			keys = output
-		return r3sponse.success_response(f"Successfully listed the agent's keys.", {
+		return r3sponse.success(f"Successfully listed the agent's keys.", {
 			"keys":keys,
 		})
 
@@ -277,21 +277,21 @@ class Agent(object):
 
 		# checks.
 		if not raw and not os.path.exists(public_key):
-			return r3sponse.error_response(f"Public key path [{public_key}] does not exist.")
+			return r3sponse.error(f"Public key path [{public_key}] does not exist.")
 
 		# load public key.
 		if not raw:
 			try:
 				public_key = utils.__load_file__(public_key)
 			except:
-				return r3sponse.error_response(f"Failed to load public key path [{public_key}].")
+				return r3sponse.error(f"Failed to load public key path [{public_key}].")
 
 		# retrieve id from public key.
 		"""
 		try:
 			public_key_id = public_key.split("[#id:")[1].split("]")[0]
 		except IndexError:
-			return r3sponse.error_response(f"Public key [{public_key}] does not contain any id.")
+			return r3sponse.error(f"Public key [{public_key}] does not contain any id.")
 
 		# list.
 		response = self.list()
@@ -317,9 +317,9 @@ class Agent(object):
 
 		# success.
 		if success:
-			return r3sponse.success_response(f"Public key [{public_key}] is added to the ssh agent.")
+			return r3sponse.success(f"Public key [{public_key}] is added to the ssh agent.")
 		else:
-			return r3sponse.error_response(f"Public key [{public_key}] is not added to the ssh agent.")
+			return r3sponse.error(f"Public key [{public_key}] is not added to the ssh agent.")
 
 		#
 	def initialize(self):
@@ -332,18 +332,18 @@ class Agent(object):
 				l = subprocess.check_output(['eval', '"$(ssh-agent)"'], shell=True).decode()
 				output = utils.__execute__(command=["ssh-add", "-l"])
 				if "Failed to communicate" in output or "Error connecting to agent" in output:
-					return r3sponse.error_response("Failed to communicate with the ssh-agent.")
+					return r3sponse.error("Failed to communicate with the ssh-agent.")
 				else:
 					output = utils.__execute__(command=["ssh-add", "-l"])
 					if "Failed to communicate" in output or "Error connecting to agent" in output:
-						return r3sponse.error_response("Failed to communicate with the ssh-agent.")
+						return r3sponse.error("Failed to communicate with the ssh-agent.")
 			else:
 				output = utils.__execute__(command=["ssh-add", "-l"])
 				if "Failed to communicate" in output or "Error connecting to agent" in output:
-					return r3sponse.error_response("Failed to communicate with the ssh-agent.")
+					return r3sponse.error("Failed to communicate with the ssh-agent.")
 
 		# success.
-		return r3sponse.success_response(f"Successfully initialized the ssh agent.")
+		return r3sponse.success(f"Successfully initialized the ssh agent.")
 
 # Initialized objects.
 agent = Agent()
