@@ -22,11 +22,54 @@ class Aliases(object):
 		items = []
 		for key in self.list(): items.append([key, CONFIG["aliases"][key]])
 		return items
-	def check(self, alias):
-		try: CONFIG["aliases"][alias]
+	def check(self, 
+		# the alias to check.
+		alias, 
+		# the info to check.
+		# 	adds / replaces the current (except the exceptions).
+		info={},
+		# the info key exceptions.
+		exceptions=[],
+		# the info value exceptions.
+		value_exceptions=[],
+		# create if not present (must also specify all required info when enabled).
+		create=False,
+	):
+
+		# get info.
+		current_info, exits = {}, False
+		try: current_info = CONFIG["aliases"][alias]
 		except KeyError:
-			return r3sponse.error(f"Alias {alias} does not exist.")
+			exits = False
+			if not create:
+				return r3sponse.error(f"Alias {alias} does not exist.")
+
+		# check existing config.
+		if exits:
+			edits, current_info_keys = 0, list(current_info.keys())
+			for info_key, info_value in info.items():
+				do = False
+				if info_key not in exceptions and info_key not in current_info_keys: do = True
+				elif info_value not in value_exceptions and info_key in current_info_keys and info_value != current_info[info_key]: do = True
+				if do:
+					current_info[info_key] = info_value
+					edits += 1
+
+		# create non existant.
+		elif not exists and create:
+
+			return self.create(
+				alias=alias,)
+
+		# save edits.
+		if edits > 0:
+			CONFIG["aliases"][alias] = current_info
+			utils.save_config_safely()
+
+		# handler.
 		return r3sponse.success(f"Successfully checked alias {alias}.")
+
+		#
 	def check_duplicate(self, alias):
 		try: CONFIG["aliases"][alias]
 		except KeyError:
@@ -42,16 +85,17 @@ class Aliases(object):
 		response = self.check(alias)
 		if not response["success"]: return response
 		del CONFIG["aliases"][alias]
-		CONFIG.save()
+		utils.save_config_safely()
 		return r3sponse.success(f"Successfully deleted alias {alias}.")
 	def edit(self, 
 		# the alias.
 		alias=None,
 		# the edits (dict).
+		# 	adds / replaces the current (except the exceptions).
 		edits={},
-		# the key exceptions.
+		# the edits key exceptions.
 		exceptions=[],
-		# the value exceptions.
+		# the edits value exceptions.
 		value_exceptions=[None],
 		# save the edits.
 		save=True,
@@ -84,7 +128,7 @@ class Aliases(object):
 		dictionary, c = edit_dict(dictionary=CONFIG.dictionary, edits=edits)
 		if c > 0 and save:
 			CONFIG.dictionary = dictionary
-			CONFIG.save()
+			utils.save_config_safely()
 		if c > 0:
 			return r3sponse.success(f"Successfully saved {c} edits for alias {alias}.")
 		else:
@@ -119,28 +163,19 @@ class Aliases(object):
 		
 		# serialized
 		if serialized != {}:
-			try:username = serialized["user"]
-			except KeyError: username = None
-			try:public_ip = serialized["public_ip"]
-			except KeyError: public_ip = None
-			try:private_ip = serialized["private_ip"]
-			except KeyError: private_ip = None
-			try:public_port = serialized["public_port"]
-			except KeyError: public_port = None
-			try:private_port = serialized["private_port"]
-			except KeyError: private_port = None
-			try:private_key = serialized["private_key"]
-			except KeyError: private_key = None
-			try:public_key = serialized["public_key"]
-			except KeyError: public_key = None
-			try:passphrase = serialized["passphrase"]
-			except KeyError: passphrase = None
-			try:smart_card = serialized["smart_card"]
-			except KeyError: smart_card = None
-			try:pin = serialized["pin"]
-			except KeyError: pin = None
-			try:alias = serialized["alias"]
-			except KeyError: alias = None
+			username, public_ip, private_ip, public_port, private_port, private_key, public_key, passphrase, smart_card, pin, alias = Dictionary(serialized).unpack({
+				"username":None,
+				"public_ip":None,
+				"private_ip":None,
+				"public_port":None,
+				"private_port":None,
+				"private_key":None,
+				"public_key":None,
+				"passphrase":None,
+				"smart_card":None,
+				"pin":None,
+				"alias":None,
+			})
 
 		# checks.
 		response = r3sponse.check_parameters({
@@ -227,7 +262,7 @@ class Aliases(object):
 		# save.
 		if save:
 			CONFIG["aliases"][alias] = json_config
-			CONFIG.save()
+			utils.save_config_safely()
 
 		# response.
 		return r3sponse.success(f"Successfully created alias [{alias}].", {
@@ -263,32 +298,51 @@ class Aliases(object):
 				if isinstance(checked["public_key"], str):
 					checked["public_key"] = syst3m.env.fill(checked["public_key"])
 				if not cl1.argument_present("--non-interactive"):
-					passphrase = None
-					if checked["smart_card"] and checked["pin"] in [False, None, "", "none", "None"]:
-						passphrase =  getpass.getpass(f"Enter the passphrase of key {checked['private_key']}:")
-					elif checked["passphrase"] in [False, None, "", "none", "None"]:
-						passphrase =  getpass.getpass(f"Enter the passphrase of key {checked['private_key']}:")
-					if checked["smart_card"]:
-						response = agent.check(public_key=checked["public_key"], raw=True)
-					else:
-						response = agent.check(public_key=checked["public_key"], raw=False)
-					if not response["success"]:
-						if "is not added" not in response["error"]: return response
-						elif "is not added" in response["error"]:
-							if checked["smart_card"]:
-								response = agent.add(path=checked["private_key"], smart_card=True, pin=passphrase)
-								if not response["success"]: return response
+					passphrase, has_passphrase, new_passphrase = None, True, True
+					if checked["smart_card"] == True:
+						if checked["pin"] in [False, None, "", "none", "None"]:
+							if checked["pin"] in [False, "", "none", "None"]:
+								has_passphrase = False
 							else:
-								response = agent.add(path=checked["private_key"], passphrase=passphrase)
-								if not response["success"]: return response
-					if passphrase not in [False, None, "", "none", "None"]:
-						response = ENCRYPTION.encrypt(passphrase)
-						if not response.success: return response
-						if checked["smart_card"]:
-							CONFIG["aliases"][alias]["pin"] = response.encrypted.decode()
+								passphrase =  getpass.getpass(f"Enter the passphrase of key {checked['private_key']}:")
 						else:
-							CONFIG["aliases"][alias]["passphrase"] = response.encrypted.decode()
-						CONFIG.save()
+							new_passphrase = False
+							response = ENCRYPTION.decrypt(checked["pin"])
+							if not response.success: return response
+							passphrase = response.decrypted.decode()
+					else:	
+						if checked["passphrase"] in [False, None, "", "none", "None"]:
+							if checked["passphrase"] in [False, "", "none", "None"]:
+								has_passphrase = False
+							else:
+								passphrase =  getpass.getpass(f"Enter the passphrase of key {checked['private_key']}:")
+						else:
+							new_passphrase = False
+							response = ENCRYPTION.decrypt(checked["passphrase"])
+							if not response.success: return response
+							passphrase = response.decrypted.decode()
+					if has_passphrase:
+						if checked["smart_card"] == True:
+							response = agent.check(public_key=checked["public_key"], raw=True)
+						else:
+							response = agent.check(public_key=checked["public_key"], raw=False)
+						if not response["success"]:
+							if "is not added" not in response["error"]: return response
+							elif "is not added" in response["error"]:
+								if checked["smart_card"]:
+									response = agent.add(path=checked["private_key"], smart_card=True, pin=passphrase)
+									if not response["success"]: return response
+								else:
+									response = agent.add(path=checked["private_key"], passphrase=passphrase)
+									if not response["success"]: return response
+						if new_passphrase:
+							response = ENCRYPTION.encrypt(passphrase)
+							if not response.success: return response
+							if checked["smart_card"] == True:
+								CONFIG["aliases"][alias]["pin"] = response.encrypted.decode()
+							else:
+								CONFIG["aliases"][alias]["passphrase"] = response.encrypted.decode()
+							utils.save_config_safely()
 				response = self.create(save=False, checks=False, serialized=Files.Dictionary(dictionary=checked).append({"alias":alias}))
 				if not response["success"]: return response
 				aliases += response["str"]
