@@ -74,7 +74,7 @@ class Installation(object):
 			fp.ownership.set(owner=username, group=None, sudo=sudo)
 
 		# success.
-		return r3sponse.success_response(f"Successfully installed ssh for user [{username}].")
+		return r3sponse.success(f"Successfully installed ssh for user [{username}].")
 
 		#
 	def check_installed(self, 
@@ -90,7 +90,7 @@ class Installation(object):
 		# users ssh directory.
 		fp = Formats.FilePath(f"{home}.ssh/")
 		if not fp.exists():
-			return r3sponse.error_response(f"Required ssh configuration file [{fp.path}] for user [{username}] is not installed.")
+			return r3sponse.error(f"Required ssh configuration file [{fp.path}] for user [{username}] is not installed.")
 		else:
 			fp.permission.set(permission=700, sudo=sudo)
 			fp.ownership.set(owner=username, group=None, sudo=sudo)
@@ -98,7 +98,7 @@ class Installation(object):
 		# the ssh config.
 		fp = Formats.FilePath(f"{home}.ssh/config")
 		if not fp.exists():
-			return r3sponse.error_response(f"Required ssh configuration file [{fp.path}] for user [{username}] is not installed.")
+			return r3sponse.error(f"Required ssh configuration file [{fp.path}] for user [{username}] is not installed.")
 		else:
 			fp.permission.set(permission=644, sudo=sudo)
 			fp.ownership.set(owner=username, group=None, sudo=sudo)
@@ -106,7 +106,7 @@ class Installation(object):
 		# the ssh known hosts.
 		fp = Formats.FilePath(f"{home}.ssh/known_hosts")
 		if not fp.exists():
-			return r3sponse.error_response(f"Required ssh configuration file [{fp.path}] for user [{username}] is not installed.")
+			return r3sponse.error(f"Required ssh configuration file [{fp.path}] for user [{username}] is not installed.")
 		else:
 			fp.permission.set(permission=644, sudo=sudo)
 			fp.ownership.set(owner=username, group=None, sudo=sudo)
@@ -114,13 +114,13 @@ class Installation(object):
 		# authorized keys.
 		fp = Formats.FilePath(f"{home}.ssh/authorized_keys")
 		if not fp.exists():
-			return r3sponse.error_response(f"Required ssh configuration file [{fp.path}] for user [{username}] is not installed.")
+			return r3sponse.error(f"Required ssh configuration file [{fp.path}] for user [{username}] is not installed.")
 		else:
 			fp.permission.set(permission=600, sudo=sudo)
 			fp.ownership.set(owner=username, group=None, sudo=sudo)
 
 		# success.
-		return r3sponse.success_response(f"SSH is successfully installed for user [{username}].")
+		return r3sponse.success(f"SSH is successfully installed for user [{username}].")
 			
 # Initialized objects.
 installation = Installation()
