@@ -90,14 +90,14 @@ class Key(object):
 
 		# checks.
 		directory = path
-		if directory[len(directory)-1] != "/": return r3sponse.error_response("The path must be a directory and end with a [/].")
+		if directory[len(directory)-1] != "/": return r3sponse.error("The path must be a directory and end with a [/].")
 		response = r3sponse.check_parameters({
 			"directory":directory,
 		})
 		if not response["success"]: return response
 
 		# check arguments.
-		if passphrase in [None, False]:
+		if passphrase in [False, None, "", "null", "None", "none"]:
 			passphrase = '""'
 
 		# create dir.
@@ -157,13 +157,13 @@ class Key(object):
 					auth_keys.permission.set(permission=600, sudo=True, silent=True) # silent for when non existant.
 					auth_keys.ownership.set(owner=username, sudo=True)
 					ssh_dir.ownership.set(owner=username, sudo=True)
-					return r3sponse.error_response(f'Public key [{key}] is not activated.')
+					return r3sponse.error(f'Public key [{key}] is not activated.')
 				if reversed and key in output:
 					ssh_dir.permission.set(permission=700, sudo=True, silent=True) # silent for when non existant.
 					auth_keys.permission.set(permission=600, sudo=True, silent=True) # silent for when non existant.
 					auth_keys.ownership.set(owner=username, sudo=True)
 					ssh_dir.ownership.set(owner=username, sudo=True)
-					return r3sponse.error_response(f'Public key [{key}] is activated.')
+					return r3sponse.error(f'Public key [{key}] is activated.')
 
 		# set correct permission.
 		ssh_dir.permission.set(permission=700, sudo=True, silent=True) # silent for when non existant.
@@ -173,9 +173,9 @@ class Key(object):
 
 		# success.
 		if not reversed:
-			return r3sponse.success_response(f'Successfully confirmed that the specfied {len(public_keys)} public key(s) are activated.')
+			return r3sponse.success(f'Successfully confirmed that the specfied {len(public_keys)} public key(s) are activated.')
 		else:
-			return r3sponse.success_response(f'Successfully confirmed that the specfied {len(public_keys)} public key(s) are not activated.')
+			return r3sponse.success(f'Successfully confirmed that the specfied {len(public_keys)} public key(s) are not activated.')
 	def enable(self, username=None, public_keys=[]):
 
 		# check if already present.
@@ -194,7 +194,7 @@ class Key(object):
 		if response["error"] != None: return response
 	
 		# success.
-		return r3sponse.success_response(f'Successfully enabled {len(public_keys)} public key(s).')
+		return r3sponse.success(f'Successfully enabled {len(public_keys)} public key(s).')
 
 		#
 	def disable(self, username=None, public_keys=[]):
@@ -214,7 +214,7 @@ class Key(object):
 		if response["error"] != None: return response
 	
 		# success.
-		return r3sponse.success_response(f'Successfully disabled {len(public_keys)} public key(s).')
+		return r3sponse.success(f'Successfully disabled {len(public_keys)} public key(s).')
 
 		#
 	def __load_keys__(self, username):
