@@ -7,8 +7,8 @@ from ssht00ls.classes import utils
 
 def __check_os__(supported=[]):
 	if OS not in supported:
-		return r3sponse.error_response(f"Unsupported operating system [{OS}].")
-	return r3sponse.success_response(f"Supported operating system [{OS}].")
+		return r3sponse.error(f"Unsupported operating system [{OS}].")
+	return r3sponse.success(f"Supported operating system [{OS}].")
 
 # the manager class.
 class SmartCards(object):
@@ -51,10 +51,10 @@ class SmartCards(object):
 					text = card.split(" Serial:")[0]
 					smart_cards[serial_number] = SmartCard(serial_number=serial_number)
 				except IndexError: 
-					return r3sponse.error_response("Unrecognized smart card detected. Remove the smart card and plug it back in.")
+					return r3sponse.error("Unrecognized smart card detected. Remove the smart card and plug it back in.")
 
 		# response.
-		return r3sponse.success_response(f"Successfully scanned & detected {len(smart_cards)} smart card(s).", {
+		return r3sponse.success(f"Successfully scanned & detected {len(smart_cards)} smart card(s).", {
 			"smart_cards":smart_cards
 		})
 
@@ -65,11 +65,11 @@ class SmartCards(object):
 		response = self.scan()
 		if response["error"] != None: return response
 		elif str(serial_number) not in list(response["smart_cards"].keys()):
-			return r3sponse.error_response(f"There is no smart card detected  with serial number [{serial_number}].")
+			return r3sponse.error(f"There is no smart card detected  with serial number [{serial_number}].")
 
 		# success.
 		smart_card = response["smart_cards"][str(serial_number)]
-		return r3sponse.success_response(f"Successfully initialzed smart card [{serial_number}].", {
+		return r3sponse.success(f"Successfully initialzed smart card [{serial_number}].", {
 			"smart_card":smart_card
 		})
 
@@ -83,14 +83,14 @@ class SmartCards(object):
 
 		# check one.
 		if len(l_response["smart_cards"]) > 1:
-			return r3sponse.error_response("There are multiple smart cards plugged in.")
+			return r3sponse.error("There are multiple smart cards plugged in.")
 
 		# check zero.
 		if len(l_response["smart_cards"]) == 0:
-			return r3sponse.error_response("There are no smart cards plugged in / detected.")
+			return r3sponse.error("There are no smart cards plugged in / detected.")
 
 		# success.
-		return r3sponse.success_response("There is only one smart cards plugged in.", {
+		return r3sponse.success("There is only one smart cards plugged in.", {
 			"smart_card":l_response["smart_cards"][list(l_response["smart_cards"].keys())[0]],
 		})
 
@@ -128,7 +128,7 @@ class SmartCard(object):
 		try: 
 			output = subprocess.check_output(f"ykman --device {self.serial_number} piv info", shell=True).decode().replace('  ',' ').replace('  ',' ').replace('  ',' ').lower().split('\n')
 		except: 
-			return r3sponse.error_response("Failed to retrieve yubikey info.")
+			return r3sponse.error("Failed to retrieve yubikey info.")
 
 		# iterate.
 		info = {}
@@ -141,7 +141,7 @@ class SmartCard(object):
 		info["serial_number"] = self.serial_number
 
 		# success.
-		return r3sponse.success_response(f"Successfully retrieved the information from smart card [{self.serial_number}].", {
+		return r3sponse.success(f"Successfully retrieved the information from smart card [{self.serial_number}].", {
 				"info":info,
 			})
 
@@ -171,10 +171,10 @@ class SmartCard(object):
 
 		# handle error.
 		if output != "":
-			return r3sponse.error_response(f"Unknown error pin unblocking, output: [{output}].")
+			return r3sponse.error(f"Unknown error pin unblocking, output: [{output}].")
 
 		# handle success.
-		return r3sponse.success_response(f"Successfully unblocked the pin code of smart card [{self.serial_number}].")
+		return r3sponse.success(f"Successfully unblocked the pin code of smart card [{self.serial_number}].")
 
 		#
 	def change_pin(self, 
@@ -203,11 +203,11 @@ class SmartCard(object):
 
 		# handle success.
 		elif "New PIN set." in output: 
-			return r3sponse.success_response(f"Successfully changed the pin of smart card [{self.serial_number}].")
+			return r3sponse.success(f"Successfully changed the pin of smart card [{self.serial_number}].")
 
 		# unknown error.
 		else:
-			return r3sponse.error_response(f"Unknown error while changing pin, output: [{output}].")
+			return r3sponse.error(f"Unknown error while changing pin, output: [{output}].")
 
 		#
 	def change_puk(self, 
@@ -237,11 +237,11 @@ class SmartCard(object):
 
 		# handle success.
 		elif "New PUK set." in output: 
-			return r3sponse.success_response(f"Successfully changed the puk of smart card [{self.serial_number}].")
+			return r3sponse.success(f"Successfully changed the puk of smart card [{self.serial_number}].")
 
 		# unknown error.
 		else:
-			return r3sponse.error_response(f"Unknown error while changing puk, output: [{output}].")
+			return r3sponse.error(f"Unknown error while changing puk, output: [{output}].")
 
 		#
 	def generate_key(self, 
@@ -265,7 +265,7 @@ class SmartCard(object):
 		response = self.__handle_default_output__(output)
 		if not response["success"]: return response
 		elif output != "":
-			return r3sponse.error_response(f"Unknown error during key generation, output: [{output}].")
+			return r3sponse.error(f"Unknown error during key generation, output: [{output}].")
 
 		# do.
 		command = f'ykman --device {self.serial_number} piv generate-certificate -s "/CN=SSH-key/" 9a public.pem --pin {pin} --management-key 010203040506070801020304050607080102030405060708'
@@ -275,10 +275,10 @@ class SmartCard(object):
 		response = self.__handle_default_output__(output)
 		if not response["success"]: return response
 		elif output != "":
-			return r3sponse.error_response(f"Unknown error during certificate generation, output: [{output}].")
+			return r3sponse.error(f"Unknown error during certificate generation, output: [{output}].")
 
 		# handle success.
-		return r3sponse.success_response(f"Successfully generated a signed certificate & key for smart card [{self.serial_number}].")
+		return r3sponse.success(f"Successfully generated a signed certificate & key for smart card [{self.serial_number}].")
 
 		#
 	def generate_management_key(self, 
@@ -302,9 +302,9 @@ class SmartCard(object):
 		response = self.__handle_default_output__(output)
 		if not response["success"]: return response
 		elif output != "":
-			return r3sponse.error_response(f"Unknown error during management key generation, output: [{output}].")
+			return r3sponse.error(f"Unknown error during management key generation, output: [{output}].")
 		else:
-			return r3sponse.success_response(f"Successfully generated a management key for smart card [{self.serial_number}].")
+			return r3sponse.success(f"Successfully generated a management key for smart card [{self.serial_number}].")
 
 		#
 	def reset_piv(self): # for when both pin & puk codes are blocked.
@@ -315,11 +315,11 @@ class SmartCard(object):
 		
 		# handle success.
 		if "Success!" in output:
-			return r3sponse.success_response("Successfully resetted the smart card.")
+			return r3sponse.success("Successfully resetted the smart card.")
 
 		# handle error.
 		else:
-			return r3sponse.error_response("Failed to reset the smart card.")
+			return r3sponse.error("Failed to reset the smart card.")
 
 	# single key plugged in compatible:
 	def export_keys(self, 
@@ -333,7 +333,7 @@ class SmartCard(object):
 		
 		# error.
 		if len(output) == 0 or "ssh-rsa " not in output[0]:
-			return r3sponse.error_response(f"Failed to export smart card [{self.serial_number}].")
+			return r3sponse.error(f"Failed to export smart card [{self.serial_number}].")
 		else:
 
 			# write out.
@@ -341,10 +341,10 @@ class SmartCard(object):
 				try:
 					utils.__save_file__(path, utils.__array_to_string__(output, joiner="\n"))
 				except:
-					return r3sponse.error_response(f"Failed to write out the exported key from smart card [{self.serial_number}].")
+					return r3sponse.error(f"Failed to write out the exported key from smart card [{self.serial_number}].")
 
 			# success.
-			return r3sponse.success_response(f"Successfully exported smart card [{self.serial_number}].", {"public_keys":output})
+			return r3sponse.success(f"Successfully exported smart card [{self.serial_number}].", {"public_keys":output})
 
 		#
 	def check_smart_card(self):
@@ -353,13 +353,13 @@ class SmartCard(object):
 		try:
 			output = subprocess.check_output("yubico-piv-tool -aversion", shell=True).decode()
 		except:
-			return r3sponse.error_response("Failed to check for yubikey smart cards.")
+			return r3sponse.error("Failed to check for yubikey smart cards.")
 
 		# success.
 		if "Application version " in output: 
-			return r3sponse.success_response("Yubikey smart card detected.", {"smart_card":True})
+			return r3sponse.success("Yubikey smart card detected.", {"smart_card":True})
 		else: 
-			return r3sponse.success_response("No yubikey smart card detected.", {"smart_card":False})
+			return r3sponse.success("No yubikey smart card detected.", {"smart_card":False})
 
 		#
 	def convert_to_smart_card(self):
@@ -379,7 +379,7 @@ class SmartCard(object):
 		l_response = self.check_smart_card()
 		if l_response["error"] != None: return l_response
 		if l_response["smart_card"]:
-			return r3sponse.success_response("The plugged in yubikey is already a smart cards.")
+			return r3sponse.success("The plugged in yubikey is already a smart cards.")
 
 		# check os.
 		response = __check_os__(["linux"])
@@ -441,10 +441,10 @@ class SmartCard(object):
 		# initialize.
 		if pin == None: 
 			pin = utils.__generate_pincode__(characters=6)
-		elif len(pin) != 6: return r3sponse.error_response("The pin code must be a six character integer code.")
+		elif len(pin) != 6: return r3sponse.error("The pin code must be a six character integer code.")
 		if puk == None: 
 			puk = utils.__generate_pincode__(characters=8)
-		elif len(puk) != 8: return r3sponse.error_response("The puk code must be a eight character integer code.")
+		elif len(puk) != 8: return r3sponse.error("The puk code must be a eight character integer code.")
 		info = {
 			"pin":pin,
 			"puk":puk,
@@ -480,7 +480,7 @@ class SmartCard(object):
 		if l_response["error"] != None: return l_response
 
 		# success.
-		return r3sponse.success_response(f"Successfully installed smart card [{self.serial_number}].", {
+		return r3sponse.success(f"Successfully installed smart card [{self.serial_number}].", {
 			"pin":info["pin"],
 			"puk":info["puk"],
 		})
@@ -495,21 +495,21 @@ class SmartCard(object):
 
 		# handle.
 		if "Incorrect PUK" in output:
-			return r3sponse.error_response(f"Provided an incorrect puk code.")
+			return r3sponse.error(f"Provided an incorrect puk code.")
 		elif "Incorrect PIN" in output:
 			info = self.get_info()
 			if info['success']: 
-				return r3sponse.error_response(f"Provided an incorrect pin code, {info['pin_attempts']} attempts left.")
+				return r3sponse.error(f"Provided an incorrect pin code, {info['pin_attempts']} attempts left.")
 			else: 
-				return r3sponse.error_response(f"Provided an incorrect pin code.")
+				return r3sponse.error(f"Provided an incorrect pin code.")
 			return response
 		elif "PUK is blocked" in output:
-			return False, r3sponse.error_response(f"The puk code of smart card [{self.serial_number}] is blocked.")
+			return False, r3sponse.error(f"The puk code of smart card [{self.serial_number}] is blocked.")
 		elif "Error: " in output:
-			return r3sponse.error_response(output.split("Error: ")[1].replace('.\n', '. ').replace('\n', ''))
+			return r3sponse.error(output.split("Error: ")[1].replace('.\n', '. ').replace('\n', ''))
 
 		# success.
-		return r3sponse.success_response("Successfully checked the output.")
+		return r3sponse.success("Successfully checked the output.")
 
 
 # initialized classes.
