@@ -57,12 +57,12 @@ def execute(
 	except subprocess.CalledProcessError as error:
 		error_, output = error.stderr, error.output
 		if isinstance(error_, bytes): error_ = error_.decode()
-		if isinstance(output, bytes): output = error_.decode()
+		if isinstance(output, bytes): output = output.decode()
 		if loader != None: loader.stop(success=False)
 		return r3sponse.error(f"Failed to execute command ({command}), (error: {error_}), (output: {output}).")
 	error_, output = proc.stderr, proc.stdout
 	if isinstance(error_, bytes): error_ = error_.decode()
-	if isinstance(output, bytes): output = error_.decode()
+	if isinstance(output, bytes): output = output.decode()
 	if error_ != "":
 		if loader != None: loader.stop(success=False)
 		return r3sponse.error(f"Failed to execute command ({command}), (error: {error_}), (output: {output}).")
