@@ -187,10 +187,10 @@ class SSHD(object):
 			fp.ownership.set(owner="root", group=None, sudo=True)
 			os.system("sudo systemctl restart ssh")
 			if not fp.exists(sudo=True):
-				return r3sponse.error_response(f"Failed to save the sshd configuration.")
+				return r3sponse.error(f"Failed to save the sshd configuration.")
 
 		# success.
-		return r3sponse.success_response("Successfully created the sshd configuration.", {
+		return r3sponse.success("Successfully created the sshd configuration.", {
 				"sshd":configuration,
 			})
 
@@ -218,7 +218,7 @@ class SSHD(object):
 			try: 
 				info["allowed_ips"]
 				if not isinstance(info["allowed_ips"], list):
-					return r3sponse.error_response(f"Invalid usage, parameter [users.{username}.allowed_ips] is supposed to be a list with allowed ip addresses.")
+					return r3sponse.error(f"Invalid usage, parameter [users.{username}.allowed_ips] is supposed to be a list with allowed ip addresses.")
 			except KeyError: info["allowed_ips"] = []
 			try: info["sftp_only"]
 			except KeyError: info["sftp_only"] = False
@@ -230,7 +230,7 @@ class SSHD(object):
 			except KeyError: info["tcp_forwarding"] = False
 
 		# response.
-		return r3sponse.success_response("Successfully checked the user items.")
+		return r3sponse.success("Successfully checked the user items.")
 
 		#
 	def __check_utils_installed__(self, usernames=[]):
@@ -258,7 +258,7 @@ class SSHD(object):
 			if response["error"] != None: return response
 
 		# success.
-		return r3sponse.success_response("Successfully verified the ssht00ls utils installation.")
+		return r3sponse.success("Successfully verified the ssht00ls utils installation.")
 
 		#
 	def __install_utils__(self, usernames=[]):
@@ -266,7 +266,7 @@ class SSHD(object):
 		# checks.
 		if isinstance(usernames, str): usernames = [usernames]
 		if len(usernames) == 0: 
-			return r3sponse.error_response("No usernames specified.")
+			return r3sponse.error("No usernames specified.")
 
 		# download.
 		path = "/tmp/utils/"
@@ -274,12 +274,12 @@ class SSHD(object):
 		os.system(f"rm -fr /tmp/ssht00ls/")
 		os.system(f'git clone https://github.com/vandenberghinc/ssht00ls /tmp/ssht00ls/')
 		if not os.path.exists(f"/tmp/ssht00ls/"):
-			return r3sponse.error_response("Failed to install the ssht00ls utils. #1")
+			return r3sponse.error("Failed to install the ssht00ls utils. #1")
 		os.system(f"mv /tmp/ssht00ls/ssht00ls/classes/utils/ {path}")
 		os.system(f"rm -fr {path}/__pycache__")
 		os.system(f"rm -fr {path}/__init__.py")
 		if not os.path.exists(path):
-			return r3sponse.error_response("Failed to install the ssht00ls utils. #2")
+			return r3sponse.error("Failed to install the ssht00ls utils. #2")
 
 		# iterate.
 		for username in usernames:
@@ -299,10 +299,10 @@ class SSHD(object):
 			fp.ownership.set(owner=username, group=None, sudo=True)
 			fp.permission.set(permission=755, recursive=True, sudo=True)
 			if not fp.exists(sudo=True):
-				return r3sponse.error_response("Failed to install the ssht00ls utils. #3")
+				return r3sponse.error("Failed to install the ssht00ls utils. #3")
 
 		# success.
-		return r3sponse.success_response("Successfully installed the ssht00ls utils.")
+		return r3sponse.success("Successfully installed the ssht00ls utils.")
 
 		#
 	def __install_banner__(self, banner="", usernames=[]):
@@ -310,7 +310,7 @@ class SSHD(object):
 		# checks.
 		if isinstance(usernames, str): usernames = [usernames]
 		if len(usernames) == 0: 
-			return r3sponse.error_response("No usernames specified.")
+			return r3sponse.error("No usernames specified.")
 
 		# save banner.
 		file = Files.File(path='/tmp/banner', data=banner)
@@ -324,10 +324,10 @@ class SSHD(object):
 			fp.permission.set(permission=755, sudo=True)
 			fp.ownership.set(owner=username, group=None, sudo=True)
 			if not fp.exists(sudo=True):
-				return r3sponse.error_response(f"Failed to install the banner for user [{username}].")
+				return r3sponse.error(f"Failed to install the banner for user [{username}].")
 
 		# success.
-		return r3sponse.success_response("Successfully installed the banner.")
+		return r3sponse.success("Successfully installed the banner.")
 
 		#
 	#
