@@ -80,9 +80,9 @@ def stop(path, timeout=SSYNC_DAEMON_SLEEPTIME*10, sleeptime=1):
 			break
 		time.sleep(sleeptime)
 	if stopped:
-		return r3sponse.success_response(f"Successfully stopped ssht00ls daemon [{path}].")
+		return r3sponse.success(f"Successfully stopped ssht00ls daemon [{path}].")
 	else:
-		return r3sponse.error_response(f"Failed to stop ssht00ls daemon [{path}].")
+		return r3sponse.error(f"Failed to stop ssht00ls daemon [{path}].")
 
 # the daemon object class.
 class Daemon(syst3m.objects.Thread):
@@ -212,7 +212,7 @@ class Daemon(syst3m.objects.Thread):
 				time.sleep(0.5)
 				response = self.delete(self.path, remote=False, subpath=False,)
 				if not response["success"]: return response
-		return r3sponse.success_response("Successfully unmounted.")
+		return r3sponse.success("Successfully unmounted.")
 	def delete(self, path, remote=False, subpath=True):
 
 		# sandbox.
@@ -232,11 +232,11 @@ class Daemon(syst3m.objects.Thread):
 			if remote:
 				msg = f"Sandbox enabled, skip deletion of {self.alias}:{str_id}."
 				if self.log_level >= 0: print(msg)
-				return r3sponse.success_response(msg)
+				return r3sponse.success(msg)
 			else:
 				msg = f"Sandbox enabled, skip deletion of {str_id}."
 				if self.log_level >= 0: print(msg)
-				return r3sponse.success_response(msg)
+				return r3sponse.success(msg)
 
 		# logs.
 		if self.log_level >= 1:
@@ -265,10 +265,10 @@ class Daemon(syst3m.objects.Thread):
 			if not response["success"]: return response
 			#response = ssh.utils.test_ssh_path(alias=self.alias, path=path)
 			#if response.error != None and f"{path} does not exist" not in response.error:
-			#	return r3sponse.error_response(f"Failed to delete {self.alias}:{path}, error: {response.error}")
+			#	return r3sponse.error(f"Failed to delete {self.alias}:{path}, error: {response.error}")
 			if response.output != "":
-				return r3sponse.error_response(f"Failed to delete {self.alias}:{str_id}, error: {output}")
-			return r3sponse.success_response(f"Successfully deleted {self.alias}:{str_id}")
+				return r3sponse.error(f"Failed to delete {self.alias}:{str_id}, error: {output}")
+			return r3sponse.success(f"Successfully deleted {self.alias}:{str_id}")
 
 		# remote to local.
 		else:
@@ -289,8 +289,8 @@ class Daemon(syst3m.objects.Thread):
 				get_output=True,)
 			if not response["success"]: return response
 			if response.output != "":
-				return r3sponse.error_response(f"Failed to delete {str_id}, error: {output}")
-			return r3sponse.success_response(f"Successfully deleted {str_id}")
+				return r3sponse.error(f"Failed to delete {str_id}, error: {output}")
+			return r3sponse.success(f"Successfully deleted {str_id}")
 	def index(self, short=False):
 
 		# index.
@@ -309,7 +309,7 @@ class Daemon(syst3m.objects.Thread):
 			try:
 				clean_index[subpath] = index[path]
 			except KeyError:
-				return r3sponse.error_response(f"Should not happen(#278363). (subpath: {subpath}), (path: {path}), (index: {json.dumps(index,indent=4)}), (remote index: {json.dumps(remote_index,indent=4)}).")
+				return r3sponse.error(f"Should not happen(#278363). (subpath: {subpath}), (path: {path}), (index: {json.dumps(index,indent=4)}), (remote index: {json.dumps(remote_index,indent=4)}).")
 		for path, mtime in remote_index.items():
 			subpath = self.subpath(path)
 			if subpath not in all_paths: 
@@ -318,7 +318,7 @@ class Daemon(syst3m.objects.Thread):
 			try:
 				remote_clean_index[subpath] = remote_index[path]
 			except KeyError:
-				return r3sponse.error_response(f"Should not happen(#739639). (subpath: {subpath}), (path: {path}), (index: {json.dumps(index,indent=4)}), (remote index: {json.dumps(remote_index,indent=4)}).")
+				return r3sponse.error(f"Should not happen(#739639). (subpath: {subpath}), (path: {path}), (index: {json.dumps(index,indent=4)}), (remote index: {json.dumps(remote_index,indent=4)}).")
 
 		# mismatches.
 		synchronized, mismatches = self.mismatches(clean_index, remote_clean_index, all_paths)
@@ -331,7 +331,7 @@ class Daemon(syst3m.objects.Thread):
 				self.last_index["0"] = clean_index
 			if self.last_remote_index == {}:
 				self.last_remote_index["0"] = remote_clean_index
-			return r3sponse.success_response(f"Successfully indexed [{self.alias}:{self.path}] & [{self.path}].", {
+			return r3sponse.success(f"Successfully indexed [{self.alias}:{self.path}] & [{self.path}].", {
 				"synchronized":synchronized,
 				"index":index,
 				"remote_index":remote_index,
@@ -398,7 +398,7 @@ class Daemon(syst3m.objects.Thread):
 						"local_mtime":lmtime,
 						"remote_mtime":rmtime,
 					}
-		return r3sponse.error_response(f"Failed to synchronize [{self.alias}:{self.remote}] & [{self.path}], mismatches: {json.dumps(mismatches, indent=4)}].")
+		return r3sponse.error(f"Failed to synchronize [{self.alias}:{self.remote}] & [{self.path}], mismatches: {json.dumps(mismatches, indent=4)}].")
 		"""
 	def process_mismatches(self, clean_index, remote_clean_index, mismatches):
 
@@ -425,7 +425,7 @@ class Daemon(syst3m.objects.Thread):
 			# should not happen.
 			if rmtime == None and lmtime == None: 
 				self.set_last_index(clean_index) ; self.set_last_index(remote_clean_index, remote=True)
-				return r3sponse.error_response(f"No remote & local modification time present. (path: {subpath}), (rmtime: {rmtime}), (lmtime: {lmtime}), (last_rmtime: {last_rmtime}), (last_lmtime: {last_lmtime}), index: {json.dumps(clean_index,indent=4)}, remote index: {json.dumps(remote_clean_index,indent=4)}.")
+				return r3sponse.error(f"No remote & local modification time present. (path: {subpath}), (rmtime: {rmtime}), (lmtime: {lmtime}), (last_rmtime: {last_rmtime}), (last_lmtime: {last_lmtime}), index: {json.dumps(clean_index,indent=4)}, remote index: {json.dumps(remote_clean_index,indent=4)}.")
 
 			# one missing.
 			elif rmtime == None or lmtime == None:
@@ -459,7 +459,7 @@ class Daemon(syst3m.objects.Thread):
 				# should not happen.
 				else:
 					self.set_last_index(clean_index) ; self.set_last_index(remote_clean_index, remote=True)
-					return r3sponse.error_response(f"Should not happen (#3243443). (path: {subpath}), (rmtime: {rmtime}), (lmtime: {lmtime}), (last_rmtime: {last_rmtime}), (last_lmtime: {last_lmtime}), index: {json.dumps(clean_index,indent=4)}, remote index: {json.dumps(remote_clean_index,indent=4)}.")
+					return r3sponse.error(f"Should not happen (#3243443). (path: {subpath}), (rmtime: {rmtime}), (lmtime: {lmtime}), (last_rmtime: {last_rmtime}), (last_lmtime: {last_lmtime}), index: {json.dumps(clean_index,indent=4)}, remote index: {json.dumps(remote_clean_index,indent=4)}.")
 
 			# both present.
 			elif rmtime != None and lmtime != None:
@@ -479,12 +479,12 @@ class Daemon(syst3m.objects.Thread):
 				# should not happen.
 				else:
 					self.set_last_index(clean_index) ; self.set_last_index(remote_clean_index, remote=True)
-					return r3sponse.error_response(f"Unable to compare rmtime: {rmtime} & lmtime: {lmtime}. (path: {subpath}), (rmtime: {rmtime}), (lmtime: {lmtime}), (last_rmtime: {last_rmtime}), (last_lmtime: {last_lmtime}), index: {json.dumps(clean_index,indent=4)}, remote index: {json.dumps(remote_clean_index,indent=4)}.")
+					return r3sponse.error(f"Unable to compare rmtime: {rmtime} & lmtime: {lmtime}. (path: {subpath}), (rmtime: {rmtime}), (lmtime: {lmtime}), (last_rmtime: {last_rmtime}), (last_lmtime: {last_lmtime}), index: {json.dumps(clean_index,indent=4)}, remote index: {json.dumps(remote_clean_index,indent=4)}.")
 
 			# exceptions.
 			else:
 				self.set_last_index(clean_index) ; self.set_last_index(remote_clean_index, remote=True)
-				return r3sponse.error_response(f"Should not happen (#407294). (path: {subpath}), (rmtime: {rmtime}), (lmtime: {lmtime}), (last_rmtime: {last_rmtime}), (last_lmtime: {last_lmtime}), index: {json.dumps(clean_index,indent=4)}, remote index: {json.dumps(remote_clean_index,indent=4)}.")
+				return r3sponse.error(f"Should not happen (#407294). (path: {subpath}), (rmtime: {rmtime}), (lmtime: {lmtime}), (last_rmtime: {last_rmtime}), (last_lmtime: {last_lmtime}), index: {json.dumps(clean_index,indent=4)}, remote index: {json.dumps(remote_clean_index,indent=4)}.")
 
 			# do not remove this exception.
 			# it is required for safe edits, to make sure a dir never gets synced unless it is created / removed.
@@ -496,7 +496,7 @@ class Daemon(syst3m.objects.Thread):
 				# add to updates.
 				if local_to_remote and remote_to_local:
 					self.set_last_index(clean_index) ; self.set_last_index(remote_clean_index, remote=True)
-					return r3sponse.error_response(f"Can not synchronize both remote to local & local to remote (rmtime: {rmtime}) (lmtime: {lmtime}), (last_rmtime: {last_rmtime}) (last_lmtime: {last_lmtime}), index: {json.dumps(clean_index,indent=4)}, remote index: {json.dumps(remote_clean_index,indent=4)}.")
+					return r3sponse.error(f"Can not synchronize both remote to local & local to remote (rmtime: {rmtime}) (lmtime: {lmtime}), (last_rmtime: {last_rmtime}) (last_lmtime: {last_lmtime}), index: {json.dumps(clean_index,indent=4)}, remote index: {json.dumps(remote_clean_index,indent=4)}.")
 				if "delete" in options: 
 					if self.log_level >= 1: 
 						if local_to_remote:
@@ -523,7 +523,7 @@ class Daemon(syst3m.objects.Thread):
 						"empty_directory":empty_directory,}
 		# handler.
 		self.set_last_index(clean_index) ; self.set_last_index(remote_clean_index, remote=True)
-		return r3sponse.success_response(f"Successfully indexed [{self.alias}:{rfullpath}] & [{lfullpath}].", {
+		return r3sponse.success(f"Successfully indexed [{self.alias}:{rfullpath}] & [{lfullpath}].", {
 			"synchronized":len(updates) == 0 and len(deletions) == 0,
 			"updates":updates,
 			"deletions":deletions,
@@ -653,9 +653,9 @@ class Daemon(syst3m.objects.Thread):
 			if self.log_level > 0:
 				print(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized.")
 			if self.log_level >= 3:
-				return r3sponse.success_response(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized, index: {json.dumps(response.index, indent=4)}, remote index: {json.dumps(response.remote_index, indent=4)}.")
+				return r3sponse.success(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized, index: {json.dumps(response.index, indent=4)}, remote index: {json.dumps(response.remote_index, indent=4)}.")
 			else:
-				return r3sponse.success_response(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized.")
+				return r3sponse.success(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized.")
 		"""
 
 		# get index.
@@ -665,9 +665,9 @@ class Daemon(syst3m.objects.Thread):
 			if self.log_level >= 1:
 				print(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized.")
 			if self.log_level >= 3:
-				return r3sponse.success_response(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized, index: {json.dumps(response.index, indent=4)}, remote index: {json.dumps(response.remote_index, indent=4)}.")
+				return r3sponse.success(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized, index: {json.dumps(response.index, indent=4)}, remote index: {json.dumps(response.remote_index, indent=4)}.")
 			else:
-				return r3sponse.success_response(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized.")
+				return r3sponse.success(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized.")
 		updates,deletions = response.unpack(["updates", "deletions"])
 		if multiprocessing and len(updates) < 50:
 			if self.log_level >= 0:
@@ -711,7 +711,7 @@ class Daemon(syst3m.objects.Thread):
 						inside_batch_size += 1
 					del depths[str(depth)]
 			if depths != {}:
-				return r3sponse.error_response(f"Should not happen(#234938). (depths: {depths}), (updates: {json.dumps(updates,indent=4)}).")
+				return r3sponse.error(f"Should not happen(#234938). (depths: {depths}), (updates: {json.dumps(updates,indent=4)}).")
 
 			# add directories.
 			for path, info in dir_updates.items():
@@ -847,10 +847,10 @@ class Daemon(syst3m.objects.Thread):
 		response = self.index(short=True)
 		if not response["success"]: return response
 		elif not response.synchronized:
-			return r3sponse.error_response(f"Failed to synchronize [{self.alias}:{self.remote}] & [{self.path}], mismatches: {json.dumps(response.mismatches, indent=4)}].")
+			return r3sponse.error(f"Failed to synchronize [{self.alias}:{self.remote}] & [{self.path}], mismatches: {json.dumps(response.mismatches, indent=4)}].")
 
 		# handler.
-		return r3sponse.success_response(f"Successfully synchronized [{self.alias}:{self.path}] & [{self.path}].")
+		return r3sponse.success(f"Successfully synchronized [{self.alias}:{self.path}] & [{self.path}].")
 	# DEPCIRATED.
 	def synchronized(self): # does not work.
 		response = self.utils.execute(
@@ -861,13 +861,13 @@ class Daemon(syst3m.objects.Thread):
 		if not response["success"]: return response
 		output = response["output"]
 		if "receiving incremental file list" not in output or "total size is" not in output or "bytes/sec" not in output:
-			return r3sponse.error_response(f"Unkown rsync output: [{output}].")
+			return r3sponse.error(f"Unkown rsync output: [{output}].")
 		b = output.split("\n")
 		try:
 			output = output[len(b[0])+1:-(len(b[len(b)-1])+len(b[len(b)-2])+3)]
 		except Exception as e:
-			return r3sponse.error_response(f"Failed to clean rsync output: [{output}]. Error: {e}; ")
+			return r3sponse.error(f"Failed to clean rsync output: [{output}]. Error: {e}; ")
 		print("OUTPUT:",output)
-		return r3sponse.success_response(f"Successfully checked [{self.alias}:{self.remote}] & [{self.path}]", {
+		return r3sponse.success(f"Successfully checked [{self.alias}:{self.remote}] & [{self.path}]", {
 			"synchronized":output == "",
 		})
\ No newline at end of file
