@@ -3,7 +3,7 @@
 
 # imports.
 import os
-from fil3s import Files, Formats, gfp
+from fil3s import *
 from r3sponse import r3sponse
 from ssht00ls.classes.config import * 
 from ssht00ls.classes.ssh import ssh
@@ -32,7 +32,7 @@ def serialize_path(path, append_last_slash=False):
 # get the size of a dir.
 def size(path, alias=None, log_level=0):
 	if alias == None:
-		return r3sponse.success_response(f"Successfully retrieved the size of {path}.", {
+		return r3sponse.success(f"Successfully retrieved the size of {path}.", {
 			"size":Formats.FilePath(path).size(mode="MB"),
 		})
 	else:
@@ -118,7 +118,7 @@ def pull(
 	if not os.path.exists(base): 
 		os.system(f"mkdir -p {base}")
 		if not os.path.exists(base): 
-			return r3sponse.error_response(f"Failed to create pull base {base}.")
+			return r3sponse.error(f"Failed to create pull base {base}.")
 		if log_level >= 3:
 			print(f"Created directory {base}.")
 
@@ -208,7 +208,7 @@ def push(
 		# dir.
 		if directory == None: directory = os.path.isdir(path)
 		elif directory and not os.path.isdir(path):
-			return r3sponse.error_response(f"Path {path} is not a directory.")
+			return r3sponse.error(f"Path {path} is not a directory.")
 
 	# check remote base.
 	# must be excluded from the checks == False.
